﻿function Prompt-StringInput([string]$PromptMessage, [switch]$ValidateNotNullOrEmpty, [string[]]$DomainOfInputValues, [string]$InputRequestedMessage = 'Input Required') {
    [bool]$Done = $false
    [string]$UserInput = $null

    while(-not $Done) {
      if($DomainOfInputValues -ne $null -and $DomainOfInputValues.Length -gt 0) {
            Write-Host "Allowed Values:- $($DomainOfInputValues -join ', ')" -ForegroundColor Cyan
      }
      $UserInput = Read-Host -Prompt $PromptMessage 
      if($ValidateNotNullOrEmpty -and ($UserInput -eq $null -or $UserInput.Length -lt 1)) {
         Write-Host $InputRequestedMessage -ForegroundColor Red
      }
      else {
        if($ValidateNotNullOrEmpty -and ($DomainOfInputValues -ne $null -and $DomainOfInputValues.Length -gt 0)) {
            if($DomainOfInputValues.Contains($UserInput)) {
                $Done = $true
            } 
            else {
                Write-Host "Invalid Value. Allowed values are:- $($DomainOfInputValues -join ', ')" -ForegroundColor Red
            }
        }else {
            $Done = $true
        }
      }
    }
    return $UserInput
}

function Prompt-Credentials([string]$PromptMessage, [string]$ConfirmPromptMessage, [switch]$ValidateNotNullOrEmpty, [switch]$Confirm, [string]$UserName) {
    
    [bool]$Done = $false
    while(-not $Done) {
        [PSCredential]$UserInputCreds = Get-Credential -UserName $UserName -Message $PromptMessage
        if($UserInputCreds -eq $null) {
            # User Cancelled the dialog
            return $null
        }
        if($ValidateNotNullOrEmpty) {
            if($UserInputCreds.Password.Length -lt 1) {
                Write-Host "Please enter a password" -ForegroundColor Red
            }
            elseif($UserInputCreds.UserName.Length -lt 1) {
                Write-Host "Please enter a user name" -ForegroundColor Red
            }else{
                $Done = $true
            }
        }else {
            $Done = $true
        }       
    }

    if($Confirm) {
        $Done = $false
        if($ConfirmPromptMessage -eq $null -or $ConfirmPromptMessage.Length -lt 1) {
            $ConfirmPromptMessage = $PromptMessage
        }
        while(-not $Done) {
            [PSCredential]$UserInputCreds2 = Get-Credential -UserName $UserInputCreds.GetNetworkCredential().UserName -Message $ConfirmPromptMessage
            if($UserInputCreds2 -eq $null) {
                # User Cancelled the dialog
                return $null
            }
            if($ValidateNotNullOrEmpty) {
                if($UserInputCreds2.Password.Length -lt 1) {
                    Write-Host 'Please enter a password' -ForegroundColor Red
                }
                elseif($UserInputCreds2.UserName.Length -lt 1) {
                    Write-Host 'Please enter a user name' -ForegroundColor Red
                }
                elseif($UserInputCreds2.UserName -ne $UserInputCreds.UserName) {
                    Write-Host "UserName $($UserInputCreds2.UserName) does not match previous entry $($UserInputCreds.UserName)" -ForegroundColor Red
                }
                elseif($UserInputCreds2.GetNetworkCredential().Password -ne $UserInputCreds.GetNetworkCredential().Password) {
                    Write-Host 'Password does not match previous entry' -ForegroundColor Red
                }
                else{
                    $Done = $true
                }
            }else {
                $Done = $true
            }       
        }
        return $UserInputCreds2
    }
    else {
        return $UserInputCreds
    }
}

function Prompt-FileLocation([string]$PromptMessage, [string]$Filter) {
    [System.Reflection.Assembly]::LoadWithPartialName("System.windows.forms") | Out-Null
    [System.Windows.Forms.OpenFileDialog]$OpenFileDialog = New-Object 'System.Windows.Forms.OpenFileDialog'
    $OpenFileDialog.Title = $PromptMessage
    $OpenFileDialog.Filter = $Filter
    $OpenFileDialog.ShowDialog() | Out-Null
    return $OpenFileDialog.FileName
}