﻿function Create-RandomString([int]$MaxLength=16) 
{
  if ($MaxLength -lt 1) {
    throw ("Invalid value MaxLength input parameter : $MaxLength")
  }

  $str = ""   # random part
  do {
    $str += (Get-Random).toString() 
  } while ($str.Length -lt $MaxLength) 

  $result = $str.Substring(0,$MaxLength)
  return  $result
}

function Connect-ToAzure([string]$PublishSettingsFile, [string]$SubscriptionName, [string]$StorageAccountName)
{
    $AzureModulePath = "$env:SystemDrive\Program Files (x86)\Microsoft SDKs\Windows Azure\PowerShell\ServiceManagement\Azure\Azure.psd1"
    $AzureModule = Import-Module $AzureModulePath -ErrorAction Stop -PassThru
    Write-Output "Current Azure PS module version : $($AzureModule.Version)"

    if (!(Test-Path $PublishSettingsFile)) {
        throw  "Publish settings file not found : $PublishSettingsFile"
    }                                                                                                                                      
    Import-AzurePublishSettingsFile $PublishSettingsFile -ErrorAction Stop -Verbose 
    if($StorageAccountName -ne $null -and $StorageAccountName.Length -gt 0) {
        Set-AzureSubscription -SubscriptionName $SubscriptionName -CurrentStorageAccountName $StorageAccountName -ErrorAction Stop -Verbose  
        Select-AzureSubscription -SubscriptionName $SubscriptionName -Current -ErrorAction Stop -Verbose   
    }
    else {
        Set-AzureSubscription -SubscriptionName $SubscriptionName -ErrorAction Stop -Verbose 
        Select-AzureSubscription -SubscriptionName $SubscriptionName -Current -ErrorAction Stop -Verbose
    }
}

function Create-StorageAccountContext([string]$StorageAccountName)
{
    if(-not(Test-AzureName -Storage $StorageAccountName)){
        New-AzureStorageAccount -StorageAccountName $StorageAccountName -Location $Location
    }

    $StorageAccountKey = (Get-AzureStorageKey -StorageAccountName $StorageAccountName).Primary
    if (!$StorageAccountKey) {
        throw "Invalid storage key. Make provide a valid storage account : $StorageAccountName"
    }
    $StorageContext = New-AzureStorageContext -StorageAccountName $StorageAccountName -StorageAccountKey $StorageAccountKey
    $StorageContext
}

function Validate-ImageNameAndLocation([string]$ImageLabel, [string]$Location)
{
    $image = Get-AzureVMImage -ErrorAction Stop | Where-Object {($_.Label -ieq $ImageLabel)} 
    if (!$image) {
        throw "Image $ImageLabel not found in Azure Image repository. Please provide a correct stock image label name."
    }

    $azLoc = Get-AzureLocation | Where {$_.Name -ieq $Location}
    if (!$azLoc) {
        throw "Location $Location is not in the list of locations available for the current Azure subscription. Please try another location."
    }
    $image
}

function Create-UploadableFileObject([string]$FileAbsolutePath,[string]$FilePathOnStorage)
{
    return @{
        FileName = Split-Path $FileAbsolutePath -Leaf;
        AbsolutePath = $FileAbsolutePath;
        PathOnStorage = $FilePathOnStorage;        
    }
}

function Get-AvailableAzureLocations([string]$AvailableService = 'PersistentVMRole') {
    $Locations = @()
    Get-AzureLocation | Where-Object { $_.AvailableServices.Contains($AvailableService) } | ForEach-Object { $Locations += $_.Name }
    $Locations
}